
# Type: macromolecular machine to biological process association_object




URI: [biolink:macromolecular_machine_to_biological_process_association_object](https://w3id.org/biolink/vocab/macromolecular_machine_to_biological_process_association_object)


## Domain and Range

[MacromolecularMachineToBiologicalProcessAssociation](MacromolecularMachineToBiologicalProcessAssociation.md) ->  <sub>REQ</sub> [BiologicalProcess](BiologicalProcess.md)

## Parents

 *  is_a: [functional association➞object](functional_association_object.md)

## Children


## Used by

 * [MacromolecularMachineToBiologicalProcessAssociation](MacromolecularMachineToBiologicalProcessAssociation.md)
